pub struct DurablePromotionBurn { /* private fields */ }Expand description
Proof that one promotion identity was appended and fsynced before result publication. The retained nonblocking lock is held until this value drops.
Implementations
Sourceimpl DurablePromotionBurn
impl DurablePromotionBurn
Sourcepub const fn record(&self) -> &PreacceptanceJournalRecord
pub const fn record(&self) -> &PreacceptanceJournalRecord
Durable preacceptance private-journal record consumed by this transaction.
Sourcepub const fn transaction_identity(&self) -> &PromotionTransactionIdentity
pub const fn transaction_identity(&self) -> &PromotionTransactionIdentity
Typed run/intent/burn identity durably consumed by this token.