pub struct PromotionFailure { /* private fields */ }Expand description
Sealed nonterminal failure record. Its five terminal fields are always false and cannot be set by the caller.
Implementations
Sourceimpl PromotionFailure
impl PromotionFailure
Sourcepub fn new(
transaction: &PromotionTransactionIdentity,
error: &PromotionError,
) -> Self
pub fn new( transaction: &PromotionTransactionIdentity, error: &PromotionError, ) -> Self
Converts an internal failure to a nonpromotable canonical envelope.